Index: vorbize.c
===================================================================
RCS file: /usr/local/cvsroot/vorbis/vorbis-tools/vorbize.c,v
retrieving revision 1.7
diff -u -r1.7 vorbize.c
--- vorbize.c	2000/07/02 03:41:44	1.7
+++ vorbize.c	2000/07/31 07:29:27
@@ -65,8 +65,8 @@
   unsigned char nocomment;
   char *single_comment;
   char *artist;
+  char *title;
   char *album;
-  char *track;
   char *read_file;
   char *write_file;
   FILE *instream;
@@ -82,8 +82,8 @@
   {"nocomment", 0, 0, 'n'},
   {"comment", 1, 0, 'c'},
   {"artist", 1, 0, 'a'},
+  {"title", 1, 0, 't'},
   {"album", 1, 0, 'l'},
-  {"track", 1, 0, 't'},
   {"write", 1, 0, 'w'},
   {"quiet", 0, 0, 'q'},
   {"raw", 0, 0, 'r'},
@@ -176,16 +176,18 @@
   fprintf (o, " -r, --raw        treat input as raw\n");
   fprintf (o, " -h, --help       this help\n");
   fprintf (o, " -v, --verbose    enable verbose output\n");
-  fprintf (o, " -q, --quiet      don't display progress\n\n");
+  fprintf (o, " -q, --quiet      don't display progress\n");
+  fprintf (o, "\n");
   fprintf (o, "Comments:\n");
   fprintf (o, " If you do not want to specify any comment, use\n");
   fprintf (o, "  -n, --nocomment encodes no comments\n");
   fprintf (o, " If you want just one comment, use\n");
   fprintf (o, "  -c, --comment=c sets the comment to c\n");
-  fprintf (o, " If you want the full artist/album/track format, use\n");
+  fprintf (o, " If you want the full artist/title/album format, use\n");
   fprintf (o, "  -a, --artist=a  sets the artist field to a\n");
+  fprintf (o, "  -t, --title=t   sets the title field to t\n");
   fprintf (o, "  -l, --album=l   sets the album field to l\n");
-  fprintf (o, "  -t, --track=t   sets the track field to t\n\n");
+  fprintf (o, "\n");
   fprintf (o,
 	   "By default, Vorbize reads from standard input and writes to standard output.\n");
   fprintf (o,
@@ -256,7 +258,7 @@
 	  break;
 	case 'n':
 	  if (param.single_comment || param.artist || param.album
-	      || param.track)
+	      || param.title)
 	    {
 	      fprintf (stderr,
 		       "Warning: null comment when comments given.\n");
@@ -266,19 +268,19 @@
 		my_free (param.artist);
 	      if (param.album)
 		my_free (param.album);
-	      if (param.track)
-		my_free (param.track);
+	      if (param.title)
+		my_free (param.title);
 	    }
 	  param.nocomment = 1;
 	  break;
-	case 't':		/* Track */
-	  if (param.track != NULL)
+	case 't':		/* Track title */
+	  if (param.title != NULL)
 	    {
 	      fprintf (stderr,
-		       "Warning: more than one track given. Using last one.\n");
-	      my_free (param.track);
+		       "Warning: more than one title given. Using last one.\n");
+ 	      my_free (param.title);
 	    }
-	  param.track = strdup (optarg);
+	  param.title = strdup (optarg);
 	  break;
 	case 'v':		/* Verbose */
 	  param.verbose++;
@@ -299,16 +301,16 @@
 		  my_free (param.single_comment);
 		}
 	      if (param.artist != NULL ||
-		  param.album != NULL || param.track != NULL)
+		  param.album != NULL || param.title != NULL)
 		{
 		  fprintf (stderr,
 			   "You cannot use both comment formats at the same time.\n");
 		  if (param.artist != NULL)
 		    my_free (param.artist);
+		  if (param.title != NULL)
+		    my_free (param.title);
 		  if (param.album != NULL)
 		    my_free (param.album);
-		  if (param.track != NULL)
-		    my_free (param.track);
 		}
 	      param.single_comment = strdup (optarg);
 	    }
@@ -364,7 +366,7 @@
     }
 
   if (param.single_comment == NULL && param.artist == NULL &&
-      param.album == NULL && param.track == NULL && !param.nocomment)
+      param.album == NULL && param.title == NULL && !param.nocomment)
     {
       fprintf (stderr,
 	       "Using default comment. Use -n if you want no comment.\n");
@@ -478,8 +480,8 @@
          vorbis_comment_add (&vc, temp);
          free (temp);
       }
-      if (param.track) {
-         temp = strcat_memsafe ("TITLE=", param.track);
+      if (param.title) {
+         temp = strcat_memsafe ("TITLE=", param.title);
          vorbis_comment_add (&vc, temp);
          free (temp);
       }
@@ -528,8 +530,8 @@
       else
 	{
 	  fprintf (stderr, "Artist:  %s\n", param.artist);
+	  fprintf (stderr, "Title:   %s\n", param.title);
 	  fprintf (stderr, "Album:   %s\n", param.album);
-	  fprintf (stderr, "Track:   %s\n", param.track);
 	}
       fprintf (stderr, "Input file information:\n");
       fprintf (stderr, "Samples per second: %li\n", fmt.samples_per_sec);
@@ -641,10 +643,10 @@
     my_free (param.single_comment);
   if (param.artist != NULL)
     my_free (param.artist);
+  if (param.title != NULL)
+    my_free (param.title);
   if (param.album != NULL)
     my_free (param.album);
-  if (param.track != NULL)
-    my_free (param.track);
   my_free (param.read_file);
   my_free (param.write_file);
   /* Close streams, again for good measure. */
